@@ -6,6 +6,7 @@ import java.util.List;
 
 import org.gcube.portlets.user.gisviewer.client.Constants;
 import org.gcube.portlets.user.gisviewer.client.GisViewerPanel;
+import org.gcube.portlets.user.gisviewer.client.commons.beans.BoundsMap;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.GisViewerBaseLayerInterface;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItem;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.MapViewInfo;
@@ -25,6 +26,7 @@ import org.gwtopenmaps.openlayers.client.control.MousePosition;
 import org.gwtopenmaps.openlayers.client.control.MousePositionOptions;
 import org.gwtopenmaps.openlayers.client.control.MousePositionOutput;
 import org.gwtopenmaps.openlayers.client.control.NavToolbar;
+import org.gwtopenmaps.openlayers.client.control.Navigation;
 import org.gwtopenmaps.openlayers.client.control.PanZoomBar;
 import org.gwtopenmaps.openlayers.client.control.ZoomBox;
 import org.gwtopenmaps.openlayers.client.event.MapClickListener;
@@ -55,12 +57,20 @@ public class OpenLayersMap {
 	protected static final int MAX_ZINDEX = 280;
 	private List<LayerItem> layerItems = new ArrayList<LayerItem>();
 	private Map map;
+	private ContentPanel cpMapWidget;
+	/**
+	 * @return the map
+	 */
+	public Map getMap() {
+		return map;
+	}
+
 	private MapWidget mapWidget;
 	private HashMap<String, String> mapping = new HashMap<String, String>();
 	private HashMap<LayerItem, Layer> mappingLayerItemsToLayers = new HashMap<LayerItem, Layer>();
 	private HashMap<Layer, LayerItem> mappingLayersToLayerItems = new HashMap<Layer, LayerItem>();
 	private NavToolbar mouseToolBar;
-	private MouseDefaults mouseDefaults;
+	private Navigation navigation;
 	//private OverviewMap overViewMap;
 	//private MouseClickOnMap mouseClickOnMap;
 //	private ToolBarPanelOld toolBarPanel;
@@ -72,8 +82,6 @@ public class OpenLayersMap {
 	private String tableTransect = "";
 	private String fieldTransect = "";
 	private VectorFeature prevVf;
-	public static Bounds defaultBounds = new Bounds(-180, -90, 180, 90);// -180, -90, 180, 90 //-20037508.34,-20037508.34,20037508.34,20037508.34);// TODO -180, -90, 180, 90);
-	public static String defaultProjection = "EPSG:4326";
 	private List<Layer> baseLayers = new ArrayList<Layer>();
 	private String transectUrl;
 	//private static String defaultProjection = "EPSG:900913";//"EPSG:4326";
@@ -116,8 +124,7 @@ public class OpenLayersMap {
 		}
 	}
 	// constructor
-	public OpenLayersMap(String w, String h, int numZoomLevels, // projection, transectUrl removed
-			String title, final OpenLayersHandler handler) {
+	public OpenLayersMap(String w, String h, int numZoomLevels, String title, final OpenLayersHandler handler) {
 
 		this.handler = handler;
 		this.numZoomLevels = numZoomLevels;
@@ -127,19 +134,18 @@ public class OpenLayersMap {
 		MapOptions mapOptions = new MapOptions();
 		mapOptions.setControls(new JObjectArray(new JSObject[] {}));
 		mapOptions.setNumZoomLevels(numZoomLevels);
-		mapOptions.setProjection(defaultProjection);
-		
+		mapOptions.setProjection(Constants.defaultProjection);
 		mapOptions.setZIndexBase(new ZIndexBaseGisViewer());
-		
+//		mapOptions.getJSObject().setProperty("displayProjection", Constants.defaultProjection);
 
+		
 		// let's create map widget and map objects
 		mapWidget = new MapWidget(w, h, mapOptions); // map widget
 		map = mapWidget.getMap(); // map js-mapped object		
 		mapWidget.setTitle(title); // set title
-		map.setMaxExtent(defaultBounds);
-
-		//map.getJSObject().setProperty("allOverlays", true);
-
+		map.setMaxExtent(Constants.defaultBounds);
+		map.setMinMaxZoomLevel(Constants.defaultOpenLayersMapDefaultZoom, numZoomLevels);
+		
 		// set click listener on the map
 		map.addMapClickListener(new MapClickListener() {
 			public void onClick(MapClickEvent mapClickEvent) {
@@ -173,24 +179,27 @@ public class OpenLayersMap {
 		});
 
 		// set the other controls
-		mouseDefaults = new MouseDefaults();
+		navigation = new Navigation();
 		mouseToolBar = new NavToolbar();
 		PanZoomBar pamZoomBar = new PanZoomBar();
 		zoomBox = new ZoomBox();
 
-		Element e = mouseDefaults.getJSObject().getPropertyAsDomElement("position");
+		
+		//ACTIVE THIS IF USE MOUSEDEFAULTS CONTROL - ONLY OPENLAYERS <= 2.12
+		/*
+		Element e = navigation.getJSObject().getPropertyAsDomElement("position");
 		e.setPropertyDouble("x", -300);
-		mouseDefaults.getJSObject().setProperty("position", e);
+		navigation.getJSObject().setProperty("position", e);
+		*/
 
-	
 		VectorOptions vectoroptions = new VectorOptions();
 		vectoroptions.setDisplayInLayerSwitcher(false);
 		vectoroptions.setDisplayOutsideMaxExtent(true);
-		vectoroptions.setProjection(defaultProjection);
+		vectoroptions.setProjection(Constants.defaultProjection);
 		vectorLayer = new Vector("transet", vectoroptions);
 		map.addLayer(vectorLayer);
 		vectorLayer.setZIndex(MAX_ZINDEX);
-		
+
 //		addBaseLayers();
 
 		String wmsURI = GisViewerPanel.resources.baseLayer().getText();
@@ -198,7 +207,7 @@ public class OpenLayersMap {
 		String[] params = wmsURI.split("\\?");
 		
 		if(params.length<2){
-			GWT.log("ERROR: No base layer found!");
+			Constants.info("","ERROR: No base layer found!");
 		}
 		
 		String baseLayerURI = params[0];
@@ -214,13 +223,12 @@ public class OpenLayersMap {
 		}
 		
 		if(baseLayerURI==null || baseLayerURI.isEmpty() || baseLayerName.isEmpty()){
-			GWT.log("ERROR: No base layer found!");
+			Window.alert("ERROR: No base layer found!");
 		}
 			
-		
 		addBaseLayerToOpenLayerMap("True Marble", baseLayerName, baseLayerURI);
-		
-		addControl(mouseDefaults);
+
+		addControl(navigation);
 		addControl(pamZoomBar);
 		addControl(getMousePosition());
 		addControl(zoomBox);
@@ -319,20 +327,19 @@ public class OpenLayersMap {
 		MousePositionOutput mpOut = new MousePositionOutput() {
 			@Override
 			public String format(LonLat lonLat, Map map) {
-				String out = "";
-				out += "<table bgcolor=\"#000000\">";
+				String out = "<table bgcolor=\"#4B79B4\">";
 				out += "<tr><td>";
 				out += "<font color=\"#FFFFFF\" align=\"left\"><b>Latitude</b></font></td>";
-				out += "<td bgcolor=\"#AAAAAA\"><font color=\"#000000\">";
+				out += "<td bgcolor=\"#D9D9DF\"><font style=\"padding: 5px;\" color=\"#9694A2\"><b>";
 				out += Util.getFormattedLonLat(lonLat.lat(), "", "");
 				// out += lonLat.lat();
-				out += "</font></td>";
+				out += "</b></font></td>";
 				out += "<td>";
 				out += "<font color=\"#FFFFFF\" align=\"left\"><b>Longitude</b></font></td>";
-				out += "<td bgcolor=\"#AAAAAA\"><font color=\"#000000\">";
+				out += "<td bgcolor=\"#D9D9DF\"><font style=\"padding: 5px;\" color=\"#9694A2\"><b>";
 				out += Util.getFormattedLonLat(lonLat.lon(), "lon", "");
 				// out += lonLat.lon();
-				out += "</font></td></tr>";
+				out += "</b></font></td></tr>";
 				out += "</table>";
 
 				return out;
@@ -381,26 +388,10 @@ public class OpenLayersMap {
 		}
 
 		map.addLayers(layers);
-		//vectorLayer.setZIndex(MAX_ZINDEX);
-		
-		// OverviewMapOptions overOptions = new OverviewMapOptions();
-		// Layer[] ls = new Layer[1];
-		// ls[0] = layers[0];
-		//
-		// overOptions.setLayers(ls);
-		//
-		// if (Constants.isOverViewMapVisible) {
-		// overViewMap = new OverviewMap();
-		// addControl(overViewMap);
-		// }
 	}
 
-//	public void addToolBarOld(ToolBarPanelOld toolBarPanel) {
-//		this.toolBarPanel = toolBarPanel;
-//	}
-//
 	/**
-	 * @param toolBarPanel2
+	 * @param toolBarPanel
 	 */
 	public void addToolBar(ToolBarPanel toolBarPanel) {
 		this.toolBarPanel = toolBarPanel;
@@ -417,8 +408,8 @@ public class OpenLayersMap {
 	public Widget getDockPanel() {
 		// int zoom=map.getZoomForExtent(map.getMaxExtent(), true);
 		// let's center the map to somewhere and set zoom level to 5
-		LonLat center = new LonLat(0, 0);
-		map.setCenter(center, Constants.openLayersMapDefaultZoom);
+		/*LonLat center = new LonLat(0, 0);
+		map.setCenter(center, Constants.openLayersMapDefaultZoom);*/
 		// map.setCenter(center, zoom);
 
 		// eventually add the map widget to div:map
@@ -434,19 +425,19 @@ public class OpenLayersMap {
 	}
 
 	public ContentPanel getContentPanel() {
-		ContentPanel panel = new ContentPanel();
-		panel.setHeaderVisible(false);
-		panel.setLayout(new FitLayout());
-		panel.add(mapWidget);
-		panel.setTopComponent(toolBarPanel);
+		cpMapWidget = new ContentPanel();
+		cpMapWidget.setHeaderVisible(false);
+		cpMapWidget.setLayout(new FitLayout());
+		cpMapWidget.add(mapWidget);
+		cpMapWidget.setTopComponent(toolBarPanel);
 		
-		// int zoom=map.getZoomForExtent(map.getMaxExtent(), true);
-		// let's center the map to somewhere and set zoom level to 5
 		LonLat center = new LonLat(0, 0);
-		map.setCenter(center, Constants.openLayersMapDefaultZoom);
-		// map.setCenter(center, zoom);
+		map.setCenter(center,Constants.defaultOpenLayersMapDefaultZoom);
 
-		return panel;
+//		Constants.info("getContentPanel", "getZoomForExtent: "+map.getZoom());
+//		Constants.info("minZoomLevel", ": "+map.getJSObject().getProperty("minZoomLevel"));
+		
+		return cpMapWidget;
 	}
 
 	public void setOpacity(LayerItem layerItem, double opacity) {
@@ -478,6 +469,15 @@ public class OpenLayersMap {
 	public void zoomToMaxExtent() {
 		this.map.zoomToMaxExtent();
 	}
+	
+	/*
+	public void centerMap(int zoom){
+		this.map.setCenter(new LonLat(0, 0), zoom);
+	}
+	
+	public void centerMapCurrentZoom(){
+		this.map.setCenter(new LonLat(0, 0), map.getZoom());
+	}*/
 
 	public String getProjection() {
 		return this.map.getProjection();
@@ -519,9 +519,9 @@ public class OpenLayersMap {
 
 	public void activatePan(boolean isActivate) {
 		if (isActivate)
-			mouseDefaults.activate();
+			navigation.activate();
 		else
-			mouseDefaults.deactivate();
+			navigation.deactivate();
 	}
 
 	// added by gianpaolo coro in 13-07-11 for returning to cache when
@@ -596,19 +596,35 @@ public class OpenLayersMap {
 		return fieldTransect;
 	}
 
-	public void changeSize(String w, String h) {
+	public void changeSize(int w, int h) {
 		// if together are positives
-		if (Integer.parseInt(w) > 0 && Integer.parseInt(h) > 0) {
-			mapWidget.setWidth(w);
-			mapWidget.setHeight(h);
-			this.updateSize();
+		
+		
+		if (w > 0 && h > 0) {
+			
+			String width = Integer.toString(w-Constants.mapPanelSpacingX);
+			String heigth = Integer.toString(h-Constants.mapPanelSpacingY);
+			Constants.info("changeSize", "New width: "+width +" new heigth: "+heigth);
+			if(Integer.parseInt(width) > 0 && Integer.parseInt(heigth)>0){
+				
+//				if(Integer.parseInt(width)>1000)
+//					width = "1000";
+//				
+				mapWidget.setWidth(width+"px");
+				mapWidget.setHeight(heigth+"px");
+				this.updateSize();
+			}
+
 		}
-		// mapWidget.setSize(w, h);
 	}
 
 	public void updateSize() {
-		map.updateSize();
-		Constants.info("Update size", "(" + getMapWidth() + ","	+ getMapHeight() + ")");
+		mapWidget.getMap().updateSize();
+//		mapWidget.getMap().setCenter(new LonLat(0, 0));
+//		mapWidget.getMap().zoomToMaxExtent();
+//		Constants.info("\n\nMap updateSize", "(" + getMapWidth() + ","	+ getMapHeight() + ") zoom: "+map.getZoom());
+//		Constants.info("Map updateSize", "Extent: "+ map.getMaxExtent() + ", Resolution:"	+ map.getMaxResolution());
+//		Constants.info("Map updateSize", "getZoomForExtent: "+ map.getZoomForExtent(Constants.defaultBounds, false));
 	}
 
 	public int getMapWidth() {
@@ -689,9 +705,6 @@ public class OpenLayersMap {
 			}
 			GWT.log("layer: "+layerItem.getName()+" setting ZIndex: "+newOrder);
 			layer.setZIndex(newOrder);
-		
-			//OLD COD
-//			layer.setZIndex(maxZindex + (int)layerItem.getOrder());
 		}
 	}
 
@@ -812,21 +825,27 @@ public class OpenLayersMap {
 		wmsOptions.setIsBaseLayer(layerItem.isBaseLayer());
 		wmsOptions.setBuffer(2); // from serviceimpl
 		wmsOptions.setWrapDateLine(true); // default
+		
+		BoundsMap maxExtent = layerItem.getMaxExtent();
+		if(maxExtent!=null){
+			GWT.log(layerItem.getName()+", Max extent Map Found: "+maxExtent);
+			wmsOptions.setMaxExtent(new Bounds(maxExtent.getLowerLeftX(), maxExtent.getLowerLeftY(), maxExtent.getUpperRightX(), maxExtent.getUpperRightY()));
+		}else{
+			GWT.log(layerItem.getName()+", Max extent is null settings: "+Constants.defaultBounds);
+			wmsOptions.setMaxExtent(Constants.defaultBounds);
+		}
+		
+		wmsOptions.setProjection(Constants.defaultProjection);
+//		wmsOptions.getJSObject().setProperty("displayProjection", Constants.defaultProjection);
+		
+//		wmsOptions.setDisplayOutsideMaxExtent(false);
 		WMSParams wmsParams = new WMSParams();
 		wmsParams.setLayers(layerItem.getLayer());
-		wmsParams.setIsTransparent(!layerItem.isBaseLayer());
+		wmsParams.setTransparent(!layerItem.isBaseLayer());
 		wmsParams.setFormat("image/png");
-		//wmsParams.setMaxExtent(defaultBounds);
-		
+//		wmsParams.setMaxExtent(Constants.defaultBounds);
 		
 		Layer layer = new WMS(layerItem.getTitle(), layerItem.getGeoserverWmsUrl(), wmsParams, wmsOptions);
-
-
-		//TODO
-
-//		System.out.println("layer.getJSObject().toString() "+layer.getJSObject().createJSObject().toString());
-		
-
 		layer.setDisplayInLayerSwitcher(displayInLayerSwitcher);
 		mappingLayerItemsToLayers.put(layerItem, layer);
 		mappingLayersToLayerItems.put(layer, layerItem);
@@ -866,4 +885,8 @@ public class OpenLayersMap {
 			prevVf = null;
 		}
 	}
+	
+	public VectorFeature getDataFeature(){
+		return prevVf;
+	}
 }
